@@ -34,6 +34,7 @@
 
 #include <assert.h>
 #include <string.h>
+#include <stdio.h>
 #include <ctype.h>
 
 int harp_csv_parse_double(char **str, double *value)
@@ -126,11 +127,6 @@ int harp_csv_parse_string(char **str, char **value)
     }
     if (cursor[stringlength] == '\0')
     {
-        if (stringlength == 0)
-        {
-            harp_set_error(HARP_ERROR_INVALID_FORMAT, "could not parse string value from csv element");
-            return -1;
-        }
         *str = &cursor[stringlength];
     }
     else
@@ -222,7 +218,7 @@ int harp_csv_parse_variable_name_and_unit(char **str, char **variable_name, char
         {
             if (*cursor != ' ')
             {
-                harp_set_error(HARP_ERROR_INVALID_FORMAT, "invalid trailing characters in csv element", cursor);
+                harp_set_error(HARP_ERROR_INVALID_FORMAT, "invalid trailing characters in csv element");
                 return -1;
             }
             cursor++;
@@ -231,57 +227,3 @@ int harp_csv_parse_variable_name_and_unit(char **str, char **variable_name, char
 
     return 0;
 }
-
-int harp_csv_get_num_lines(FILE *file, const char *filename, long *new_num_lines)
-{
-    long length;
-    char LINE[HARP_CSV_LINE_LENGTH];
-    long num_lines = 0;
-
-    while (fgets(LINE, HARP_CSV_LINE_LENGTH, file) != NULL)
-    {
-        /* Trim the line */
-        length = (long)strlen(LINE);
-        while (length > 0 && (LINE[length - 1] == '\r' || LINE[length - 1] == '\n'))
-        {
-            length--;
-        }
-        LINE[length] = '\0';
-
-        /* Do not allow empty lines */
-        if (length == 0)
-        {
-            harp_set_error(HARP_ERROR_INVALID_ARGUMENT, "empty line in file '%s'", filename);
-            return -1;
-        }
-
-        num_lines++;
-    }
-
-    *new_num_lines = num_lines;
-    return 0;
-}
-
-/* Modifies the string end */
-void harp_csv_rtrim(char *str)
-{
-    size_t length = strlen(str);
-
-    while (length > 0 && (str[length - 1] == '\r' || str[length - 1] == '\n' || str[length - 1] == '\t' ||
-                          str[length - 1] == ' '))
-    {
-        length--;
-    }
-    str[length] = '\0';
-}
-
-/* Returns a pointer to a substring */
-char *harp_csv_ltrim(char *str)
-{
-    while (isspace(str[0]))
-    {
-        str++;
-    }
-
-    return str;
-}
