@@ -32,16 +32,11 @@
 #ifndef HARP_CSV_H
 #define HARP_CSV_H
 
-#include <stdio.h>
-
 #define HARP_CSV_LINE_LENGTH 4096
 
 int harp_csv_parse_double(char **str, double *value);
 int harp_csv_parse_long(char **str, long *value);
 int harp_csv_parse_string(char **str, char **value);
 int harp_csv_parse_variable_name_and_unit(char **str, char **variable_name, char **unit);
-int harp_csv_get_num_lines(FILE *file, const char *filename, long *new_num_lines);
-void harp_csv_rtrim(char *str);
-char *harp_csv_ltrim(char *str);
 
 #endif
