@@ -549,8 +549,8 @@ int harp_ingestion_module_aeolus_l2b_init(void)
     const char *description;
 
     description = "AEOLUS Level 2B Product";
-    module = harp_ingestion_register_module_coda("AEOLUS_L2B", "AEOLUS", "AEOLUS", "ALD_U_N_2B", description,
-                                                 ingestion_init, ingestion_done);
+    module = harp_ingestion_register_module("AEOLUS_L2B", "AEOLUS", "AEOLUS", "ALD_U_N_2B", description,
+                                            ingestion_init, ingestion_done);
     harp_ingestion_register_option(module, "data", "the type of profiles to ingest; option values are 'rayleigh' "
                                    "(default), 'mie'", 2, dataset_options);
 
