@@ -1662,8 +1662,8 @@ int harp_ingestion_module_geoms_ftir_init(void)
     harp_ingestion_module *module;
     int i;
 
-    module = harp_ingestion_register_module_coda("GEOMS-TE-FTIR", "GEOMS", "GEOMS", "FTIR", "GEOMS template for FTIR",
-                                                 ingestion_init, ingestion_done);
+    module = harp_ingestion_register_module("GEOMS-TE-FTIR", "GEOMS", "GEOMS", "FTIR", "GEOMS template for FTIR",
+                                            ingestion_init, ingestion_done);
 
     for (i = 0; i < num_ftir_gas; i++)
     {
