@@ -2168,7 +2168,7 @@ static harp_product_definition *register_measurement_product(harp_ingestion_modu
         "4, 2, or 1 measurement(s) respectively for this band in a scan. ";
     harp_product_definition_add_mapping(product_definition, description, NULL);
     description = "Some readouts may even cover multiple scans if the integration time is larger than 6s. HARP will "
-        "combine the data for all bands into a single two-dimensional pixel_readout array and uses a fixed resulotion "
+        "combine the data for all bands into a single two-dimensional pixel_readout array and uses a fixed resolution "
         "of 187.5ms for the variables. Because bands might have higher integration time this means that for those "
         "bands there will be multiple rows in the pixel_readout array for a single readout. ";
     harp_product_definition_add_mapping(product_definition, description, NULL);
@@ -2196,8 +2196,8 @@ int harp_ingestion_module_gome2_l1_init(void)
     const char *description;
 
     description = "GOME2 Level 1 data";
-    module = harp_ingestion_register_module_coda("GOME2_L1", "GOME-2", "EPS", "GOME_xxx_1B", description,
-                                                 ingestion_init, ingestion_done);
+    module = harp_ingestion_register_module("GOME2_L1", "GOME-2", "EPS", "GOME_xxx_1B", description,
+                                            ingestion_init, ingestion_done);
     harp_ingestion_register_option(module, "band", "only include data from the specified band ('band-1a', 'band-1b', "
                                    "'band-2a', 'band-2b', 'band-3', 'band-4'); by default data from all bands is "
                                    "retrieved", 6, band_name_as_option);
