@@ -330,8 +330,7 @@ static void register_aerosol_product(void)
     const char *path;
 
     description = "OSIRIS Level 2";
-    module =
-        harp_ingestion_register_module_coda("OSIRIS_L2_Aerosol_MART", "OSIRIS", "ODIN_OSIRIS", "L2_Aerosol_MART",
+    module = harp_ingestion_register_module("OSIRIS_L2_Aerosol_MART", "OSIRIS", "ODIN_OSIRIS", "L2_Aerosol_MART",
                                             description, ingestion_init_aerosol, ingestion_done);
 
     description = "profile data";
@@ -429,8 +428,8 @@ static void register_no2_oe_product(void)
     const char *path;
 
     description = "OSIRIS Level 2";
-    module = harp_ingestion_register_module_coda("OSIRIS_L2_NO2_OE", "OSIRIS", "ODIN_OSIRIS", "L2_NO2_OE", description,
-                                                 ingestion_init_no2_oe, ingestion_done);
+    module = harp_ingestion_register_module("OSIRIS_L2_NO2_OE", "OSIRIS", "ODIN_OSIRIS", "L2_NO2_OE", description,
+                                            ingestion_init_no2_oe, ingestion_done);
 
     description = "profile data";
     product_definition = harp_ingestion_register_product(module, "OSIRIS_L2_NO2_OE", description, read_dimensions);
@@ -532,8 +531,8 @@ static void register_no2_mart_product(void)
     const char *path;
 
     description = "OSIRIS Level 2";
-    module = harp_ingestion_register_module_coda("OSIRIS_L2_NO2_MART", "OSIRIS", "ODIN_OSIRIS", "L2_NO2_MART",
-                                                 description, ingestion_init_no2_mart, ingestion_done);
+    module = harp_ingestion_register_module("OSIRIS_L2_NO2_MART", "OSIRIS", "ODIN_OSIRIS", "L2_NO2_MART",
+                                            description, ingestion_init_no2_mart, ingestion_done);
 
     description = "profile data";
     product_definition = harp_ingestion_register_product(module, "OSIRIS_L2_NO2_MART", description, read_dimensions);
@@ -635,8 +634,8 @@ static void register_o3_oe_product(void)
     const char *path;
 
     description = "OSIRIS Level 2";
-    module = harp_ingestion_register_module_coda("OSIRIS_L2_O3_OE", "OSIRIS", "ODIN_OSIRIS", "L2_O3_OE", description,
-                                                 ingestion_init_o3_oe, ingestion_done);
+    module = harp_ingestion_register_module("OSIRIS_L2_O3_OE", "OSIRIS", "ODIN_OSIRIS", "L2_O3_OE", description,
+                                            ingestion_init_o3_oe, ingestion_done);
 
     description = "profile data";
     product_definition = harp_ingestion_register_product(module, "OSIRIS_L2_O3_OE", description, read_dimensions);
@@ -738,8 +737,7 @@ static void register_o3_mart_product(void)
     const char *path;
 
     description = "OSIRIS Level 2";
-    module =
-        harp_ingestion_register_module_coda("OSIRIS_L2_O3_MART", "OSIRIS", "ODIN_OSIRIS", "L2_O3_MART", description,
+    module = harp_ingestion_register_module("OSIRIS_L2_O3_MART", "OSIRIS", "ODIN_OSIRIS", "L2_O3_MART", description,
                                             ingestion_init_o3_mart, ingestion_done);
 
     description = "profile data";
