@@ -254,7 +254,7 @@ static int enable_include_for_species_in_file(ingest_info *info)
     /* We can't read the speciesname with with coda_cursor_read_string  */
     /* because that yields a 1-char string and cursor_read_array fails  */
     /* because the type is text and not an array. Also, the size of the */
-    /* name varies. Therefor we first get the size and read size chars. */
+    /* name varies. Therefore we first get the size and read size chars. */
     if (coda_cursor_get_array_dim(&cursor, &num_dims, dims) != 0)
     {
         harp_set_error(HARP_ERROR_CODA, NULL);
@@ -640,8 +640,7 @@ int harp_ingestion_module_smr_l2_init(void)
     const char *path;
 
     description = "SMR Level 2";
-    module =
-        harp_ingestion_register_module_coda("SMR_L2", "SMR", "ODIN_SMR", "L2", description, ingestion_init,
+    module = harp_ingestion_register_module("SMR_L2", "SMR", "ODIN_SMR", "L2", description, ingestion_init,
                                             ingestion_done);
 
     description = "profile data";
