@@ -556,23 +556,17 @@ static void ingestion_option_definition_delete(harp_ingestion_option_definition
 
 static int ingestion_module_new(const char *name, const char *product_group, const char *product_class,
                                 const char *product_type, const char *description,
-                                int (*ingestion_init_coda) (const harp_ingestion_module *module, coda_product *product,
-                                                            const harp_ingestion_options *options,
-                                                            harp_product_definition **definition, void **user_data),
-                                int (*verify_product_type) (const harp_ingestion_module *module, const char *filename),
-                                int (*ingestion_init_custom) (const harp_ingestion_module *module, const char *filename,
-                                                              const harp_ingestion_options *options,
-                                                              harp_product_definition **definition, void **user_data),
+                                int (*ingestion_init) (const harp_ingestion_module *module, coda_product *product,
+                                                       const harp_ingestion_options *options,
+                                                       harp_product_definition **definition, void **user_data),
                                 void (*ingestion_done) (void *user_data), harp_ingestion_module **new_module)
 {
     harp_ingestion_module *module;
 
     assert(name != NULL);
     assert(product_group != NULL);
-    assert((ingestion_init_coda != NULL) != (ingestion_init_custom != NULL));
-    assert((ingestion_init_coda != NULL) == (product_class != NULL && product_type != NULL));
+    assert((ingestion_init != NULL) == (product_class != NULL && product_type != NULL));
     assert((product_class != NULL) == (product_type != NULL));
-    assert((ingestion_init_custom != NULL) == (verify_product_type != NULL));
     assert(ingestion_done != NULL);
 
     module = (harp_ingestion_module *)malloc(sizeof(harp_ingestion_module));
@@ -609,9 +603,7 @@ static int ingestion_module_new(const char *name, const char *product_group, con
     module->product_definition = NULL;
     module->num_option_definitions = 0;
     module->option_definition = NULL;
-    module->ingestion_init_coda = ingestion_init_coda;
-    module->verify_product_type = verify_product_type;
-    module->ingestion_init_custom = ingestion_init_custom;
+    module->ingestion_init = ingestion_init;
     module->ingestion_done = ingestion_done;
 
     *new_module = module;
@@ -784,47 +776,19 @@ static int read_index(void *user_data, long index, harp_array data)
     return 0;
 }
 
-harp_ingestion_module *harp_ingestion_register_module_coda(const char *name, const char *product_group,
-                                                           const char *product_class, const char *product_type,
-                                                           const char *description,
-                                                           int (*ingestion_init) (const harp_ingestion_module *module,
-                                                                                  coda_product *product,
-                                                                                  const harp_ingestion_options *options,
-                                                                                  harp_product_definition **definition,
-                                                                                  void **user_data),
-                                                           void (*ingestion_done) (void *user_data))
+harp_ingestion_module *harp_ingestion_register_module(const char *name, const char *product_group,
+                                                      const char *product_class, const char *product_type,
+                                                      const char *description,
+                                                      int (*ingestion_init) (const harp_ingestion_module *module,
+                                                                             coda_product *product,
+                                                                             const harp_ingestion_options *options,
+                                                                             harp_product_definition **definition,
+                                                                             void **user_data),
+                                                      void (*ingestion_done) (void *user_data))
 {
     harp_ingestion_module *module;
 
-    if (ingestion_module_new(name, product_group, product_class, product_type, description, ingestion_init, NULL, NULL,
-                             ingestion_done, &module) != 0)
-    {
-        assert(0);
-    }
-
-    if (ingestion_register_module(module) != 0)
-    {
-        assert(0);
-    }
-
-    return module;
-}
-
-harp_ingestion_module *harp_ingestion_register_module_custom(const char *name, const char *product_group,
-                                                             const char *description,
-                                                             int (*verify_product_type) (const harp_ingestion_module
-                                                                                         *module, const char *filename),
-                                                             int (*ingestion_init) (const harp_ingestion_module *module,
-                                                                                    const char *filename,
-                                                                                    const harp_ingestion_options
-                                                                                    *options,
-                                                                                    harp_product_definition
-                                                                                    **definition, void **user_data),
-                                                             void (*ingestion_done) (void *user_data))
-{
-    harp_ingestion_module *module;
-
-    if (ingestion_module_new(name, product_group, NULL, NULL, description, NULL, verify_product_type, ingestion_init,
+    if (ingestion_module_new(name, product_group, product_class, product_type, description, ingestion_init,
                              ingestion_done, &module) != 0)
     {
         assert(0);
@@ -1306,25 +1270,6 @@ int harp_ingestion_find_module(const char *filename, harp_ingestion_module **mod
             harp_set_error(HARP_ERROR_CODA, NULL);
             return -1;
         }
-
-        /* Could not identify product using CODA => try verify_product_type() for custom modules */
-        for (i = 0; i < module_register->num_ingestion_modules; i++)
-        {
-            harp_ingestion_module *ingestion_module;
-
-            ingestion_module = module_register->ingestion_module[i];
-            if (ingestion_module->verify_product_type == NULL)
-            {
-                continue;
-            }
-            if (ingestion_module->verify_product_type(ingestion_module, filename) != 0)
-            {
-                continue;
-            }
-
-            *module = ingestion_module;
-            return 0;
-        }
     }
 
     harp_set_error(HARP_ERROR_UNSUPPORTED_PRODUCT, "%s: unsupported product", filename);
