@@ -1641,20 +1641,23 @@ static int execute_polygon_filter(ingest_info *info, harp_program *program)
 
 static int execute_exclude_variable(ingest_info *info, harp_operation_exclude_variable *operation)
 {
-    int index;
-    int j;
+    int i, j;
 
-    /* unmark the variables to exclude */
-    for (j = 0; j < operation->num_variables; j++)
+    for (i = 0; i < info->product_definition->num_variable_definitions; i++)
     {
-        index = harp_product_definition_get_variable_index(info->product_definition, operation->variable_name[j]);
-        if (index < 0)
-        {
-            /* non-existent variable, not an error */
-            continue;
-        }
+        const char *variable_name = info->product_definition->variable_definition[i]->name;
 
-        info->variable_mask[index] = 0;
+        if (info->variable_mask[i])
+        {
+            for (j = 0; j < operation->num_variables; j++)
+            {
+                if (harp_match_wildcard(operation->variable_name[j], variable_name))
+                {
+                    info->variable_mask[i] = 0;
+                    break;
+                }
+            }
+        }
     }
 
     return 0;
@@ -1662,46 +1665,43 @@ static int execute_exclude_variable(ingest_info *info, harp_operation_exclude_va
 
 static int execute_keep_variable(ingest_info *info, harp_operation_keep_variable *operation)
 {
-    uint8_t *included;
-    int index;
-    int j;
+    int i, j;
 
-    included = (uint8_t *)calloc(info->product_definition->num_variable_definitions, sizeof(uint8_t));
-    if (included == NULL)
+    for (i = 0; i < info->product_definition->num_variable_definitions; i++)
     {
-        harp_set_error(HARP_ERROR_OUT_OF_MEMORY, "out of memory (could not allocate %lu bytes) (%s:%u)",
-                       info->product_definition->num_variable_definitions * sizeof(uint8_t), __FILE__, __LINE__);
-        return -1;
+        const char *variable_name = info->product_definition->variable_definition[i]->name;
+
+        if (info->variable_mask[i])
+        {
+            int included = 0;
+
+            for (j = 0; j < operation->num_variables; j++)
+            {
+                if (harp_match_wildcard(operation->variable_name[j], variable_name))
+                {
+                    included = 1;
+                    break;
+                }
+            }
+
+            info->variable_mask[i] = included;
+        }
     }
 
-    /* assume all variables are excluded */
-    for (j = 0; j < info->product_definition->num_variable_definitions; j++)
-    {
-        included[j] = 0;
-    }
-
-    /* set the 'keep' flags in the mask */
     for (j = 0; j < operation->num_variables; j++)
     {
-        index = harp_product_definition_get_variable_index(info->product_definition, operation->variable_name[j]);
-        if (index < 0 || info->variable_mask[index] == 0)
+        if (strchr(operation->variable_name[j], '*') == NULL && strchr(operation->variable_name[j], '?') == NULL)
         {
-            harp_set_error(HARP_ERROR_OPERATION, "cannot keep non-existent variable %s", operation->variable_name[j]);
-            free(included);
-            return -1;
+            i = harp_product_definition_get_variable_index(info->product_definition, operation->variable_name[j]);
+            if (i < 0 || info->variable_mask[i] == 0)
+            {
+                harp_set_error(HARP_ERROR_OPERATION, "cannot keep non-existent variable %s",
+                               operation->variable_name[j]);
+                return -1;
+            }
         }
-
-        included[index] = 1;
     }
 
-    /* filter the variables using the mask */
-    for (j = info->product_definition->num_variable_definitions - 1; j >= 0; j--)
-    {
-        info->variable_mask[j] = info->variable_mask[j] && included[j];
-    }
-
-    free(included);
-
     return 0;
 }
 
@@ -1922,24 +1922,11 @@ static int ingest(const char *filename, harp_program *program, const harp_ingest
         ingestion_done(info);
         return -1;
     }
-    if (info->cproduct != NULL && info->module->ingestion_init_coda != NULL)
+    if (info->module->ingestion_init(info->module, info->cproduct, option_list, &info->product_definition,
+                                     &info->user_data) != 0)
     {
-        if (info->module->ingestion_init_coda(info->module, info->cproduct, option_list, &info->product_definition,
-                                              &info->user_data) != 0)
-        {
-            ingestion_done(info);
-            return -1;
-        }
-    }
-    else
-    {
-        assert(info->module->ingestion_init_custom != NULL);
-        if (info->module->ingestion_init_custom(info->module, filename, option_list, &info->product_definition,
-                                                &info->user_data) != 0)
-        {
-            ingestion_done(info);
-            return -1;
-        }
+        ingestion_done(info);
+        return -1;
     }
     assert(info->product_definition != NULL);
 
@@ -2037,12 +2024,21 @@ int harp_ingest(const char *filename, const char *operations, const char *option
     return status;
 }
 
-static int ingest_metadata(const char *filename, const harp_ingestion_options *option_list, double *datetime_start,
-                           double *datetime_stop, long dimension[])
+static int ingest_metadata(const char *filename, const harp_ingestion_options *option_list,
+                           harp_product_metadata *metadata)
 {
     ingest_info *info;
     int i;
 
+    /* the source_product always equals the filename for ingestions */
+    metadata->source_product = strdup(harp_basename(filename));
+    if (metadata->source_product == NULL)
+    {
+        harp_set_error(HARP_ERROR_OUT_OF_MEMORY, "out of memory (could not duplicate string) (%s:%u)", __FILE__,
+                       __LINE__);
+        return -1;
+    }
+
     if (ingestion_init(&info) != 0)
     {
         return -1;
@@ -2057,27 +2053,24 @@ static int ingest_metadata(const char *filename, const harp_ingestion_options *o
         ingestion_done(info);
         return -1;
     }
-    if (info->cproduct != NULL && info->module->ingestion_init_coda != NULL)
+    assert(info->cproduct != NULL);
+    if (info->module->ingestion_init(info->module, info->cproduct, option_list, &info->product_definition,
+                                     &info->user_data) != 0)
     {
-        if (info->module->ingestion_init_coda(info->module, info->cproduct, option_list, &info->product_definition,
-                                              &info->user_data) != 0)
-        {
-            ingestion_done(info);
-            return -1;
-        }
-    }
-    else
-    {
-        assert(info->module->ingestion_init_custom != NULL);
-        if (info->module->ingestion_init_custom(info->module, filename, option_list, &info->product_definition,
-                                                &info->user_data) != 0)
-        {
-            ingestion_done(info);
-            return -1;
-        }
+        ingestion_done(info);
+        return -1;
     }
     assert(info->product_definition != NULL);
 
+    /* the format metadata field is equal to the product definition name */
+    metadata->format = strdup(info->product_definition->name);
+    if (metadata->format == NULL)
+    {
+        harp_set_error(HARP_ERROR_OUT_OF_MEMORY, "out of memory (could not duplicate string) (%s:%u)", __FILE__,
+                       __LINE__);
+        return -1;
+    }
+
     info->basename = harp_basename(filename);
 
     if (harp_product_new(&info->product) != 0)
@@ -2091,12 +2084,9 @@ static int ingest_metadata(const char *filename, const harp_ingestion_options *o
         ingestion_done(info);
         return -1;
     }
-    if (dimension != NULL)
+    for (i = 0; i < HARP_NUM_DIM_TYPES; i++)
     {
-        for (i = 0; i < HARP_NUM_DIM_TYPES; i++)
-        {
-            dimension[i] = info->dimension[i];
-        }
+        metadata->dimension[i] = info->dimension[i];
     }
     if (init_variable_mask(info) != 0)
     {
@@ -2107,15 +2097,16 @@ static int ingest_metadata(const char *filename, const harp_ingestion_options *o
     if (product_has_empty_dimensions(info) || !product_has_variables(info))
     {
         /* empty product is not considered an error */
-        *datetime_start = harp_mininf();
-        *datetime_stop = harp_plusinf();
+        metadata->datetime_start = harp_mininf();
+        metadata->datetime_stop = harp_plusinf();
         ingestion_done(info);
         return 0;
     }
 
     if (info->product_definition->read_datetime_range != NULL)
     {
-        if (info->product_definition->read_datetime_range(info->user_data, datetime_start, datetime_stop) != 0)
+        if (info->product_definition->read_datetime_range(info->user_data, &metadata->datetime_start,
+                                                          &metadata->datetime_stop) != 0)
         {
             ingestion_done(info);
             return -1;
@@ -2152,7 +2143,7 @@ static int ingest_metadata(const char *filename, const harp_ingestion_options *o
             }
         }
 
-        if (harp_product_get_datetime_range(info->product, datetime_start, datetime_stop) != 0)
+        if (harp_product_get_datetime_range(info->product, &metadata->datetime_start, &metadata->datetime_stop) != 0)
         {
             ingestion_done(info);
             return -1;
@@ -2164,8 +2155,7 @@ static int ingest_metadata(const char *filename, const harp_ingestion_options *o
     return 0;
 }
 
-int harp_ingest_global_attributes(const char *filename, const char *options, double *datetime_start,
-                                  double *datetime_stop, long dimension[], char **source_product)
+int harp_ingest_metadata(const char *filename, const char *options, harp_product_metadata *metadata)
 {
     harp_ingestion_options *option_list;
     int perform_conversions;
@@ -2207,7 +2197,7 @@ int harp_ingest_global_attributes(const char *filename, const char *options, dou
     perform_boundary_checks = coda_get_option_perform_boundary_checks();
     coda_set_option_perform_boundary_checks(0);
 
-    status = ingest_metadata(filename, option_list, datetime_start, datetime_stop, dimension);
+    status = ingest_metadata(filename, option_list, metadata);
 
     /* set the libcoda options back to their original values */
     coda_set_option_perform_boundary_checks(perform_boundary_checks);
@@ -2220,18 +2210,6 @@ int harp_ingest_global_attributes(const char *filename, const char *options, dou
         return -1;
     }
 
-    if (source_product != NULL)
-    {
-        /* the source_product always equals the filename for ingestions */
-        *source_product = strdup(harp_basename(filename));
-        if (*source_product == NULL)
-        {
-            harp_set_error(HARP_ERROR_OUT_OF_MEMORY, "out of memory (could not duplicate string) (%s:%u)", __FILE__,
-                           __LINE__);
-            return -1;
-        }
-    }
-
     return 0;
 }
 
@@ -2360,17 +2338,8 @@ int harp_ingest_test(const char *filename, int (*print) (const char *, ...))
             }
             fflush(stdout);
 
-            if (info->cproduct != NULL && info->module->ingestion_init_coda != NULL)
-            {
-                status = info->module->ingestion_init_coda(info->module, info->cproduct, option_list,
-                                                           &info->product_definition, &info->user_data);
-            }
-            else
-            {
-                assert(info->module->ingestion_init_custom != NULL);
-                status = info->module->ingestion_init_custom(info->module, filename, option_list,
-                                                             &info->product_definition, &info->user_data);
-            }
+            status = info->module->ingestion_init(info->module, info->cproduct, option_list, &info->product_definition,
+                                                  &info->user_data);
             if (status == 0)
             {
                 assert(info->product_definition != NULL);
