@@ -59,17 +59,25 @@ LIBHARP_API void harp_product_metadata_delete(harp_product_metadata *metadata)
         {
             free(metadata->filename);
         }
+        if (metadata->format != NULL)
+        {
+            free(metadata->format);
+        }
         if (metadata->source_product != NULL)
         {
             free(metadata->source_product);
         }
+        if (metadata->history != NULL)
+        {
+            free(metadata->history);
+        }
         free(metadata);
     }
 }
 
 /**
  * Create new product metadata.
- * The metadata will be intialized with 0.0 datetime_start/end.
+ * The metadata will be initialized with 0.0 datetime_start/end.
  * \param new_metadata Pointer to the C variable where the new HARP product metadata will be stored.
  * \return
  *   \arg \c 0, Success.
@@ -89,7 +97,9 @@ LIBHARP_API int harp_product_metadata_new(harp_product_metadata **new_metadata)
     }
 
     metadata->filename = NULL;
+    metadata->format = NULL;
     metadata->source_product = NULL;
+    metadata->history = NULL;
 
     for (i = 0; i < HARP_NUM_DIM_TYPES; i++)
     {
@@ -143,10 +153,7 @@ LIBHARP_API void harp_product_metadata_print(harp_product_metadata *metadata, in
     }
     for (i = 0; i < HARP_NUM_DIM_TYPES; i++)
     {
-        if (metadata->dimension[i] >= 0)
-        {
-            print("%ld", metadata->dimension[i]);
-        }
+        print("%ld", metadata->dimension[i]);
         print(",");
     }
     print("%s\n", metadata->source_product);
