@@ -37,6 +37,7 @@
 #include <assert.h>
 #include <math.h>
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 
 #define MAX_NAME_LENGTH 128
@@ -646,7 +647,7 @@ void harp_profile_pressure_from_gph(long num_levels, const double *gph_profile,
     }
 }
 
-/** Sum the columns of the 2D averaging kernal to arrive at a 1D column averaging kernel
+/** Sum the columns of the 2D averaging kernel to arrive at a 1D column averaging kernel
  * The 2D averaging kernel needs to be a partial column number density AVK.
  * \param num_levels            Number of vertical levels
  * \param column_density_avk_2d 2D column number density averaging kernel {num_levels,num_levels}
@@ -667,6 +668,60 @@ void harp_profile_column_avk_from_partial_column_avk(long num_levels, const doub
     }
 }
 
+/** Create a tropospheric column AVK from a total column AVK
+ * This sets all stratosheric layers of the AVK to zero.
+ * \param num_levels            Number of vertical levels
+ * \param column_density_avk column number density averaging kernel {num_levels}
+ * \param altitude_bounds altitude boundaries {num_levels, 2}
+ * \param tropopause_altitude altitude of the tropopause
+ * \param tropospheric_column_density_avk tropospheric column number density averaging kernel {num_levels}
+ */
+void harp_profile_tropospheric_column_avk_from_column_avk(long num_levels, const double *column_density_avk,
+                                                          const double *altitude_bounds, double tropopause_altitude,
+                                                          double *tropospheric_column_density_avk)
+{
+    long i;
+
+    for (i = 0; i < num_levels; i++)
+    {
+        if (altitude_bounds[2 * i] < tropopause_altitude)
+        {
+            tropospheric_column_density_avk[i] = column_density_avk[i];
+        }
+        else
+        {
+            tropospheric_column_density_avk[i] = 0;
+        }
+    }
+}
+
+/** Create a stratospheric column AVK from a total column AVK
+ * This sets all troposheric layers of the AVK to zero.
+ * \param num_levels            Number of vertical levels
+ * \param column_density_avk column number density averaging kernel {num_levels}
+ * \param altitude_bounds altitude boundaries {num_levels, 2}
+ * \param tropopause_altitude altitude of the tropopause
+ * \param stratospheric_column_density_avk stratospheric column number density averaging kernel {num_levels}
+ */
+void harp_profile_stratospheric_column_avk_from_column_avk(long num_levels, const double *column_density_avk,
+                                                           const double *altitude_bounds, double tropopause_altitude,
+                                                           double *stratospheric_column_density_avk)
+{
+    long i;
+
+    for (i = 0; i < num_levels; i++)
+    {
+        if (altitude_bounds[2 * i + 1] <= tropopause_altitude)
+        {
+            stratospheric_column_density_avk[i] = 0;
+        }
+        else
+        {
+            stratospheric_column_density_avk[i] = column_density_avk[i];
+        }
+    }
+}
+
 /** Convert a partial column avk to a density avk using the altitude boundaries profile
  * This is a generic routine to convert partial columns to a densities. It works for all cases where the
  * conversion is a matter of dividing the partial column value by the altitude height to get the density value.
@@ -1499,7 +1554,7 @@ LIBHARP_API int harp_product_smooth_vertical_with_collocated_dataset(harp_produc
  * \param name Name of the variable that should be created.
  * \param unit Unit (optional) of the variable that should be created.
  * \param vertical_grid Variable containing the vertical grid of the column avk.
- * \param vertical_bounds Variable containig the grid boundaries of the column avk (optional).
+ * \param vertical_bounds Variable containing the grid boundaries of the column avk (optional).
  * \param column_avk Column averaging kernel variable.
  * \param apriori Apriori profile (optional).
  * \param variable Pointer to the C variable where the derived HARP variable will be stored.
