@@ -51,9 +51,11 @@ LIBHARP_API const char *libharp_version = HARP_VERSION;
 
 static int harp_init_counter = 0;
 
+int harp_option_create_collocation_datetime = 0;
 int harp_option_enable_aux_afgl86 = 0;
 int harp_option_enable_aux_usstd76 = 0;
 int harp_option_hdf5_compression = 0;
+int harp_option_propagate_uncertainty = 0;
 int harp_option_regrid_out_of_bounds = 0;
 
 typedef enum file_format_enum
@@ -207,7 +209,7 @@ static int auxiliary_data_init(void)
  * If multiple files for the same product class exist in the path, CODA will only use the one with the highest revision
  * number (this is normally equal to a last modification date that is stored in a .codadef file).
  * If there are two files for the same product class with identical revision numbers, CODA will use the definitions of
- * the first .codadef file in the path and ingore the second one.
+ * the first .codadef file in the path and ignore the second one.
  *
  * Specifying a path using this function will prevent CODA from using the CODA_DEFINITION environment variable.
  * If you still want CODA to acknowledge the CODA_DEFINITION environment variable then use something like this in your
@@ -285,6 +287,43 @@ LIBHARP_API int harp_set_coda_definition_path_conditional(const char *file, cons
     return 0;
 }
 
+/** Enable/Disable the creation of collocation_datetime variables
+ * Enabling this option will create a collocation_datetime variable when a collocate_left or collocation_right operation is performed.
+ * The collocation_datetime variable will contain the datetime of the sample from the other dataset for the collocated pair.
+ * The variable will only be created if the collocation result file contains a datetime_diff column.
+ * By default the creation of the collocation_datetime variable is disabled.
+ * \param enable
+ *   \arg 0: Disable creation of collocation_datetime variables.
+ *   \arg 1: Enable creation of collocation_datetime variables.
+ * \return
+ *   \arg \c 0, Success.
+ *   \arg \c -1, Error occurred (check #harp_errno).
+ */
+LIBHARP_API int harp_set_option_create_collocation_datetime(int enable)
+{
+    if (enable != 0 && enable != 1)
+    {
+        harp_set_error(HARP_ERROR_INVALID_ARGUMENT, "enable argument (%d) is not valid (%s:%u)", enable, __FILE__,
+                       __LINE__);
+        return -1;
+    }
+
+    harp_option_create_collocation_datetime = enable;
+
+    return 0;
+}
+
+/** Retrieve the current setting for the creation of collocation_datetime variables option.
+ * \see harp_set_option_create_collocation_datetime()
+ * \return
+ *   \arg \c 0, Creation of collocation_datetime variables is disabled.
+ *   \arg \c 1, Ceation of collocation_datetime variables is enabled.
+ */
+LIBHARP_API int harp_get_option_create_collocation_datetime(void)
+{
+    return harp_option_create_collocation_datetime;
+}
+
 /** Enable/Disable the use of AFGL86 climatology in variable conversions
  * Enabling this option will allow the derived variable functions to create variables using the built-in AFGL86
  * profiles. If datetime, latitude, and altitude variables are available then altitude regridded versions of the
@@ -412,6 +451,41 @@ LIBHARP_API int harp_get_option_hdf5_compression(void)
     return harp_option_hdf5_compression;
 }
 
+/** Set how to propagate uncertainty.
+ * This is only applicable for operations that support propagation of uncertainties. And then only if there is a choice.
+ * The propagation can either assume uncertainties to be fully uncorrelated (the default) or fully correlated.
+ * \param method
+ *   \arg 0: Assume uncertainties to be uncorrelated.
+ *   \arg 1: Assume uncertainties to be fully correlated.
+ * \return
+ *   \arg \c 0, Success.
+ *   \arg \c -1, Error occurred (check #harp_errno).
+ */
+LIBHARP_API int harp_set_option_propagate_uncertainty(int method)
+{
+    if (method < 0 || method > 1)
+    {
+        harp_set_error(HARP_ERROR_INVALID_ARGUMENT, "method argument (%d) is not valid (%s:%u)", method, __FILE__,
+                       __LINE__);
+        return -1;
+    }
+
+    harp_option_propagate_uncertainty = method;
+
+    return 0;
+}
+
+/** Retrieve the current setting for how to propagate uncertainty.
+ * \see harp_set_option_propagate_uncertainty()
+ * \return
+ *   \arg \c 0 Assume uncertainties to be uncorrelated.
+ *   \arg \c 1 Assume uncertainties to be fully correlated.
+ */
+LIBHARP_API int harp_get_option_propagate_uncertainty(void)
+{
+    return harp_option_propagate_uncertainty;
+}
+
 /** Set how to treat out of bound values during regridding operations.
  * This is only applicable for point interpolation regridding. Any point that falls outside the target grid
  * can be either set to NaN (the default), set to the nearest edge value, or set based on extrapolation (of two nearest
@@ -511,7 +585,7 @@ LIBHARP_API void harp_done(void)
             harp_unit_done();
             harp_derived_variable_list_done();
             harp_ingestion_done();
-            /* explicitly clear search paths in case unit and/or ingestion init() routines were never called */ 
+            /* explicitly clear search paths in case unit and/or ingestion init() routines were never called */
             harp_set_coda_definition_path(NULL);
             harp_set_udunits2_xml_path(NULL);
         }
@@ -719,7 +793,7 @@ LIBHARP_API int harp_import_test(const char *filename, int (*print) (const char
  * string of key=value pair; only used if the file is not in HARP format.
  * \param new_metadata Pointer to the variable where the metadata should be stored.
  * \return
- *   \arg \c 0, Succes.
+ *   \arg \c 0, Success.
  *   \arg \c -1, Error occurred (check #harp_errno).
  */
 LIBHARP_API int harp_import_product_metadata(const char *filename, const char *options,
@@ -753,8 +827,7 @@ LIBHARP_API int harp_import_product_metadata(const char *filename, const char *o
     {
         case format_hdf4:
 #ifdef HAVE_HDF4
-            result = harp_import_global_attributes_hdf4(filename, &metadata->datetime_start, &metadata->datetime_stop,
-                                                        metadata->dimension, &metadata->source_product);
+            result = harp_import_metadata_hdf4(filename, metadata);
 #else
             harp_set_error(HARP_ERROR_UNSUPPORTED_PRODUCT, NULL);
             result = -1;
@@ -762,16 +835,14 @@ LIBHARP_API int harp_import_product_metadata(const char *filename, const char *o
             break;
         case format_hdf5:
 #ifdef HAVE_HDF5
-            result = harp_import_global_attributes_hdf5(filename, &metadata->datetime_start, &metadata->datetime_stop,
-                                                        metadata->dimension, &metadata->source_product);
+            result = harp_import_metadata_hdf5(filename, metadata);
 #else
             harp_set_error(HARP_ERROR_UNSUPPORTED_PRODUCT, NULL);
             result = -1;
 #endif
             break;
         case format_netcdf:
-            result = harp_import_global_attributes_netcdf(filename, &metadata->datetime_start, &metadata->datetime_stop,
-                                                          metadata->dimension, &metadata->source_product);
+            result = harp_import_metadata_netcdf(filename, metadata);
             break;
         default:
             harp_set_error(HARP_ERROR_UNSUPPORTED_PRODUCT, NULL);
@@ -787,8 +858,7 @@ LIBHARP_API int harp_import_product_metadata(const char *filename, const char *o
         }
 
         /* try ingest */
-        if (harp_ingest_global_attributes(filename, options, &metadata->datetime_start, &metadata->datetime_stop,
-                                          metadata->dimension, &metadata->source_product) != 0)
+        if (harp_ingest_metadata(filename, options, metadata) != 0)
         {
             harp_product_metadata_delete(metadata);
             return -1;
